@@ -10,11 +10,18 @@ from typing import Any
 import exrex
 import phonenumbers
 from djmoney.contrib.django_rest_framework import MoneyField
+from drf_extra_fields import fields as extra_fields
+from drf_extra_fields.fields import *  # noqa: F403, F401
 from drf_spectacular.drainage import set_override
 from drf_spectacular.types import OpenApiTypes
 from drf_spectacular.utils import extend_schema_field
 from phonenumber_field import serializerfields
 from phonenumber_field.phonenumber import to_python
+from psycopg2._range import (
+    DateRange,
+    DateTimeTZRange,
+    NumericRange,
+)
 from rest_framework import fields
 from rest_framework.fields import *  # noqa: F403, F401
 
@@ -22,9 +29,14 @@ from django.core import validators
 
 from audoma.example_generators import generate_lorem_ipsum
 from audoma.mixins import (
+    Base64ExampleMixin,
+    DateExampleMixin,
+    DateTimeExampleMixin,
     ExampleMixin,
     NumericExampleMixin,
+    RangeExampleMixin,
     RegexExampleMixin,
+    TimeExampleMixin,
 )
 
 
@@ -34,7 +46,6 @@ field_names = [
     "EmailField",
     "SlugField",
     "URLField",
-    "DateTimeField",
     "DurationField",
     "ChoiceField",
     "MultipleChoiceField",
@@ -90,15 +101,19 @@ class MACAddressField(RegexExampleMixin, fields.CharField):
 
 
 @extend_schema_field(OpenApiTypes.DATE)
-class DateField(ExampleMixin, fields.DateField):
+class DateField(DateExampleMixin, fields.DateField):
     pass
 
 
 @extend_schema_field(OpenApiTypes.TIME)
-class TimeField(ExampleMixin, fields.TimeField):
+class TimeField(TimeExampleMixin, fields.TimeField):
     pass
 
 
+class DateTimeField(DateTimeExampleMixin, fields.DateTimeField):
+    ...
+
+
 @extend_schema_field(
     field={
         "format": "ip-address",
@@ -192,6 +207,9 @@ class SerializerMethodField(ExampleMixin, fields.Field):
         super().bind(field_name, parent)
         if self.field is not None:
             set_override(self, "field", self.field)
+        # set params for child field
+        self.field.parent = self.parent
+        self.field.field_name = self.field_name
 
     def to_representation(self, obj):
         method = getattr(self.parent, self.method_name)
@@ -209,3 +227,55 @@ class SerializerMethodField(ExampleMixin, fields.Field):
 
     def run_validation(self, data):
         return {self.field_name: self.field.run_validation(data)}
+
+
+class Base64ImageField(Base64ExampleMixin, extra_fields.Base64ImageField):
+    ...
+
+
+# TODO - provide example for this one
+# class HybridImageField(HybridImageField):
+#    ...
+
+
+class Base64FileField(Base64ExampleMixin, extra_fields.Base64FileField):
+    ...
+
+
+class RangeField(RangeExampleMixin, extra_fields.RangeField):
+    ...
+
+
+@extend_schema_field(IntegerField())
+class IntegerRangeField(RangeField):
+    child_class = IntegerField
+    default_child_attrs = {}
+    range_type = NumericRange
+
+
+@extend_schema_field(FloatField())
+class FloatRangeField(RangeField):
+    child_class = FloatField
+    default_child_attrs = {}
+    range_type = NumericRange
+
+
+@extend_schema_field(DecimalField(**{"max_digits": None, "decimal_places": None}))
+class DecimalRangeField(RangeField):
+    child_class = DecimalField
+    default_child_attrs = {"max_digits": None, "decimal_places": None}
+    range_type = NumericRange
+
+
+@extend_schema_field(DateTimeField())
+class DateTimeRangeField(RangeField):
+    child_class = DateTimeField
+    default_child_attrs = {}
+    range_type = DateTimeTZRange
+
+
+@extend_schema_field(DateField())
+class DateRangeField(RangeField):
+    child_class = DateField
+    default_child_attrs = {}
+    range_type = DateRange
