@@ -1,6 +1,8 @@
 from rest_framework import exceptions
 
 from django.conf import settings
+from django.core.exceptions import PermissionDenied
+from django.http import Http404
 
 
 WRAP_RESULT_SERIALIZER = getattr(settings, "AUDOMA_WRAP_RESULT_SERIALIZER", False)
@@ -18,6 +20,8 @@ COMMON_API_ERRORS = [
     exceptions.NotAcceptable,
     exceptions.ValidationError,
     exceptions.Throttled,
+    Http404,
+    PermissionDenied,
 ]
 
 settings.SPECTACULAR_SETTINGS["POSTPROCESSING_HOOKS"] = [
